@@ -73,7 +73,7 @@ import org.w3c.dom.ls.LSSerializer;
  * @author Joe Kesselman, IBM
  * @author Andy Clark, IBM
  * @author Ralf Pfeiffer, IBM
- * @version $Id: CoreDocumentImpl.java 449328 2006-09-23 22:58:23Z mrglavas $
+ * @version $Id: CoreDocumentImpl.java 515302 2007-03-06 21:07:10Z mrglavas $
  * @since  PR-DOM-Level-1-19980818.
  */
 
@@ -2647,21 +2647,21 @@ extends ParentNode implements Document  {
      * A method to be called when some text was changed in a text node,
      * so that live objects can be notified.
      */
-    void replacedText(NodeImpl node) {
+    void replacedText(CharacterDataImpl node) {
     }
 
     /**
      * A method to be called when some text was deleted from a text node,
      * so that live objects can be notified.
      */
-    void deletedText(NodeImpl node, int offset, int count) {
+    void deletedText(CharacterDataImpl node, int offset, int count) {
     }
 
     /**
      * A method to be called when some text was inserted into a text node,
      * so that live objects can be notified.
      */
-    void insertedText(NodeImpl node, int offset, int count) {
+    void insertedText(CharacterDataImpl node, int offset, int count) {
     }
 
     /**
