@@ -59,7 +59,7 @@ import org.apache.xerces.xni.parser.XMLInputSource;
  * @author Glenn Marcy, IBM
  * @author Eric Ye, IBM
  *
- * @version $Id: XMLDTDScannerImpl.java 454439 2006-10-09 17:45:39Z mrglavas $
+ * @version $Id: XMLDTDScannerImpl.java 572055 2007-09-02 17:55:43Z mrglavas $
  */
 public class XMLDTDScannerImpl
     extends XMLScanner
@@ -136,8 +136,8 @@ public class XMLDTDScannerImpl
     /** Seen external DTD. */
     protected boolean fSeenExternalDTD;
 
-    /** Seen external parameter entity. */
-    protected boolean fSeenExternalPE;
+    /** Seen a parameter entity reference. */
+    protected boolean fSeenPEReferences;
 
     // private data
 
@@ -175,22 +175,22 @@ public class XMLDTDScannerImpl
     // temporary variables
 
     /** Array of 3 strings. */
-    private String[] fStrings = new String[3];
+    private final String[] fStrings = new String[3];
 
     /** String. */
-    private XMLString fString = new XMLString();
+    private final XMLString fString = new XMLString();
 
     /** String buffer. */
-    private XMLStringBuffer fStringBuffer = new XMLStringBuffer();
+    private final XMLStringBuffer fStringBuffer = new XMLStringBuffer();
 
     /** String buffer. */
-    private XMLStringBuffer fStringBuffer2 = new XMLStringBuffer();
+    private final XMLStringBuffer fStringBuffer2 = new XMLStringBuffer();
 
     /** Literal text. */
-    private XMLString fLiteral = new XMLString();
+    private final XMLString fLiteral = new XMLString();
 
     /** Literal text. */
-    private XMLString fLiteral2 = new XMLString();
+    private final XMLString fLiteral2 = new XMLString();
 
     /** Enumeration values. */
     private String[] fEnumeration = new String[5];
@@ -199,7 +199,7 @@ public class XMLDTDScannerImpl
     private int fEnumerationCount;
 
     /** Ignore conditional section buffer. */
-    private XMLStringBuffer fIgnoreConditionalBuffer = new XMLStringBuffer(128);
+    private final XMLStringBuffer fIgnoreConditionalBuffer = new XMLStringBuffer(128);
 
     //
     // Constructors
@@ -635,6 +635,10 @@ public class XMLDTDScannerImpl
         throws IOException, XNIException {
         int depth = fPEDepth;
         String pName = "%"+name;
+        if (!fSeenPEReferences) {
+            fSeenPEReferences = true;
+            fEntityManager.notifyHasPEReferences();
+        }
         if (fValidation && !fEntityManager.isDeclaredEntity(pName)) {
             fErrorReporter.reportError( XMLMessageFormatter.XML_DOMAIN,"EntityNotDeclared", 
                                         new Object[]{name}, XMLErrorReporter.SEVERITY_ERROR);
@@ -1359,7 +1363,7 @@ public class XMLDTDScannerImpl
                 }
             }
             // AttValue 
-            boolean isVC = !fStandalone  &&  (fSeenExternalDTD || fSeenExternalPE) ;
+            boolean isVC = !fStandalone  &&  (fSeenExternalDTD || fSeenPEReferences);
             scanAttributeValue(defaultVal, nonNormalizedDefaultVal, atName, isVC, elName);
         }
         return defaultType;
@@ -1485,10 +1489,6 @@ public class XMLDTDScannerImpl
         String systemId = fStrings[0];
         String publicId = fStrings[1];
 
-        if (isPEDecl && systemId != null) {
-            fSeenExternalPE = true;
-        }
-
         String notation = null;
         // NDATA
         boolean sawSpace = skipSeparator(true, !scanningInternalSubset());
@@ -2107,7 +2107,7 @@ public class XMLDTDScannerImpl
 
         fStandalone = false;
         fSeenExternalDTD = false;
-        fSeenExternalPE = false;
+        fSeenPEReferences = false;
 
         // set starting state
         setScannerState(SCANNER_STATE_TEXT_DECL);
