@@ -1,64 +1,24 @@
 /*
- * The Apache Software License, Version 1.1
- *
- *
- * Copyright (c) 1999-2003 The Apache Software Foundation.  
- * All rights reserved.
- *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions
- * are met:
- *
- * 1. Redistributions of source code must retain the above copyright
- *    notice, this list of conditions and the following disclaimer. 
- *
- * 2. Redistributions in binary form must reproduce the above copyright
- *    notice, this list of conditions and the following disclaimer in
- *    the documentation and/or other materials provided with the
- *    distribution.
- *
- * 3. The end-user documentation included with the redistribution,
- *    if any, must include the following acknowledgment:  
- *       "This product includes software developed by the
- *        Apache Software Foundation (http://www.apache.org/)."
- *    Alternately, this acknowledgment may appear in the software itself,
- *    if and wherever such third-party acknowledgments normally appear.
- *
- * 4. The names "Xerces" and "Apache Software Foundation" must
- *    not be used to endorse or promote products derived from this
- *    software without prior written permission. For written 
- *    permission, please contact apache@apache.org.
- *
- * 5. Products derived from this software may not be called "Apache",
- *    nor may "Apache" appear in their name, without prior written
- *    permission of the Apache Software Foundation.
- *
- * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
- * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
- * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
- * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
- * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
- * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
- * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
- * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
- * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
- * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
- * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
- * SUCH DAMAGE.
- * ====================================================================
- *
- * This software consists of voluntary contributions made by many
- * individuals on behalf of the Apache Software Foundation and was
- * originally based on software copyright (c) 1999, International
- * Business Machines, Inc., http://www.apache.org.  For more
- * information on the Apache Software Foundation, please see
- * <http://www.apache.org/>.
+ * Licensed to the Apache Software Foundation (ASF) under one or more
+ * contributor license agreements.  See the NOTICE file distributed with
+ * this work for additional information regarding copyright ownership.
+ * The ASF licenses this file to You under the Apache License, Version 2.0
+ * (the "License"); you may not use this file except in compliance with
+ * the License.  You may obtain a copy of the License at
+ * 
+ *      http://www.apache.org/licenses/LICENSE-2.0
+ * 
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
  */
 
 package org.apache.xerces.impl.dtd;
 
 import org.apache.xerces.impl.Constants;
-import org.apache.xerces.impl.XMLDocumentFragmentScannerImpl;
+import org.apache.xerces.impl.RevalidationHandler;
 import org.apache.xerces.impl.XMLEntityManager;
 import org.apache.xerces.impl.XMLErrorReporter;
 import org.apache.xerces.impl.dtd.models.ContentModelValidator;
@@ -112,16 +72,18 @@ import org.apache.xerces.xni.parser.XMLDocumentSource;
  *  <li>http://apache.org/xml/properties/internal/grammar-pool</li>
  *  <li>http://apache.org/xml/properties/internal/datatype-validator-factory</li>
  * </ul>
+ * 
+ * @xerces.internal
  *
  * @author Eric Ye, IBM
  * @author Andy Clark, IBM
  * @author Jeffrey Rodriguez IBM
  * @author Neil Graham, IBM
  *
- * @version $Id: XMLDTDValidator.java,v 1.56 2003/12/09 07:41:28 venu Exp $
+ * @version $Id: XMLDTDValidator.java 572055 2007-09-02 17:55:43Z mrglavas $
  */
 public class XMLDTDValidator
-        implements XMLComponent, XMLDocumentFilter, XMLDTDValidatorFilter {
+        implements XMLComponent, XMLDocumentFilter, XMLDTDValidatorFilter, RevalidationHandler {
 
     //
     // Constants
@@ -136,19 +98,23 @@ public class XMLDTDValidator
 
     /** Feature identifier: namespaces. */
     protected static final String NAMESPACES =
-    Constants.SAX_FEATURE_PREFIX + Constants.NAMESPACES_FEATURE;
+        Constants.SAX_FEATURE_PREFIX + Constants.NAMESPACES_FEATURE;
 
     /** Feature identifier: validation. */
     protected static final String VALIDATION =
-    Constants.SAX_FEATURE_PREFIX + Constants.VALIDATION_FEATURE;
+        Constants.SAX_FEATURE_PREFIX + Constants.VALIDATION_FEATURE;
 
     /** Feature identifier: dynamic validation. */
     protected static final String DYNAMIC_VALIDATION = 
-    Constants.XERCES_FEATURE_PREFIX + Constants.DYNAMIC_VALIDATION_FEATURE;
+        Constants.XERCES_FEATURE_PREFIX + Constants.DYNAMIC_VALIDATION_FEATURE;
+    
+    /** Feature identifier: balance syntax trees. */
+    protected static final String BALANCE_SYNTAX_TREES =
+        Constants.XERCES_FEATURE_PREFIX + Constants.BALANCE_SYNTAX_TREES;
 
     /** Feature identifier: warn on duplicate attdef */
     protected static final String WARN_ON_DUPLICATE_ATTDEF = 
-    Constants.XERCES_FEATURE_PREFIX +Constants.WARN_ON_DUPLICATE_ATTDEF_FEATURE; 
+        Constants.XERCES_FEATURE_PREFIX + Constants.WARN_ON_DUPLICATE_ATTDEF_FEATURE; 
     
 	protected static final String PARSER_SETTINGS = 
 		Constants.XERCES_FEATURE_PREFIX + Constants.PARSER_SETTINGS;	
@@ -183,7 +149,8 @@ public class XMLDTDValidator
     private static final String[] RECOGNIZED_FEATURES = {
         NAMESPACES,
         VALIDATION,
-        DYNAMIC_VALIDATION
+        DYNAMIC_VALIDATION,
+        BALANCE_SYNTAX_TREES
     };
 
     /** Feature defaults. */
@@ -191,6 +158,7 @@ public class XMLDTDValidator
         null,
         null,
         Boolean.FALSE,
+        Boolean.FALSE,
     };
 
     /** Recognized properties. */
@@ -227,7 +195,7 @@ public class XMLDTDValidator
     protected ValidationManager fValidationManager = null;
     
     // validation state
-    protected ValidationState   fValidationState   = new ValidationState();
+    protected final ValidationState fValidationState = new ValidationState();
 
     // features
 
@@ -245,6 +213,9 @@ public class XMLDTDValidator
      * the validation feature is set to <code>true</code>.
      */
     protected boolean fDynamicValidation;
+    
+    /** Controls whether the DTD grammar produces balanced syntax trees. */
+    protected boolean fBalanceSyntaxTrees;
 
     /** warn on duplicate attribute definition, this feature works only when validation is true */
     protected boolean fWarnDuplicateAttdef;
@@ -507,6 +478,13 @@ public class XMLDTDValidator
             fDynamicValidation = false;
         }
         
+        try {
+            fBalanceSyntaxTrees = componentManager.getFeature(BALANCE_SYNTAX_TREES);
+        }
+        catch (XMLConfigurationException e) {
+            fBalanceSyntaxTrees = false;
+        }
+        
         try {
             fWarnDuplicateAttdef = componentManager.getFeature(WARN_ON_DUPLICATE_ATTDEF);
         }
@@ -759,13 +737,25 @@ public class XMLDTDValidator
         fDTDGrammar = fGrammarBucket.getGrammar(grammarDesc);
         if(fDTDGrammar == null) {
             // give grammar pool a chance...
-            if(fGrammarPool != null) {
+            //
+            // Do not bother checking the pool if no public or system identifier was provided. 
+            // Since so many different DTDs have roots in common, using only a root name as the 
+            // key may cause an unexpected grammar to be retrieved from the grammar pool. This scenario
+            // would occur when an ExternalSubsetResolver has been queried and the
+            // XMLInputSource returned contains an input stream but no external identifier.
+            // This can never happen when the instance document specified a DOCTYPE. -- mrglavas
+            if (fGrammarPool != null && (systemId != null || publicId != null)) {
                 fDTDGrammar = (DTDGrammar)fGrammarPool.retrieveGrammar(grammarDesc);
             }
         }
         if(fDTDGrammar == null) {
             // we'll have to create it...
-            fDTDGrammar = new DTDGrammar(fSymbolTable, grammarDesc);
+            if (!fBalanceSyntaxTrees) {
+                fDTDGrammar = new DTDGrammar(fSymbolTable, grammarDesc);
+            }
+            else {
+                fDTDGrammar = new BalancedDTDGrammar(fSymbolTable, grammarDesc);
+            }
         } else {
             // we've found a cached one;so let's make sure not to read
             // any external subset!
@@ -874,7 +864,7 @@ public class XMLDTDValidator
                 }
                 
                 // For E15.2
-                if (augs != null && augs.getItem(XMLDocumentFragmentScannerImpl.CHAR_REF) == Boolean.TRUE) {
+                if (augs != null && augs.getItem(Constants.CHAR_REF_PROBABLE_WS) == Boolean.TRUE) {
                     fErrorReporter.reportError(XMLMessageFormatter.XML_DOMAIN, 
                                                "MSG_CONTENT_INVALID_SPECIFIED",
                                                new Object[]{ fCurrentElement.rawname, 
@@ -1863,13 +1853,12 @@ public class XMLDTDValidator
     } // init()
 
     /** ensure element stack capacity */
-    private void ensureStackCapacity ( int newElementDepth) {
+    private void ensureStackCapacity (int newElementDepth) {
         if (newElementDepth == fElementQNamePartsStack.length) {
-            int[] newStack = new int[newElementDepth * 2];
 
             QName[] newStackOfQueue = new QName[newElementDepth * 2];
             System.arraycopy(this.fElementQNamePartsStack, 0, newStackOfQueue, 0, newElementDepth );
-            fElementQNamePartsStack      = newStackOfQueue;
+            fElementQNamePartsStack = newStackOfQueue;
 
             QName qname = fElementQNamePartsStack[newElementDepth];
             if (qname == null) {
@@ -1878,7 +1867,7 @@ public class XMLDTDValidator
                 }
             }
 
-            newStack = new int[newElementDepth * 2];
+            int[] newStack = new int[newElementDepth * 2];
             System.arraycopy(fElementIndexStack, 0, newStack, 0, newElementDepth);
             fElementIndexStack = newStack;
 
@@ -2116,4 +2105,9 @@ public class XMLDTDValidator
         return XMLChar.isSpace(c);
     } // isSpace(int):  boolean
 
+    public boolean characterData(String data, Augmentations augs) {       
+        characters(new XMLString(data.toCharArray(), 0, data.length()), augs);
+        return true;
+    }
+
 } // class XMLDTDValidator
