@@ -28,11 +28,11 @@ import java.util.Hashtable;
  *
  * @author Sandy Gao, IBM
  *
- * @version $Id: DTDDVFactoryImpl.java 446749 2006-09-15 21:51:23Z mrglavas $
+ * @version $Id: DTDDVFactoryImpl.java 572061 2007-09-02 18:05:06Z mrglavas $
  */
 public class DTDDVFactoryImpl extends DTDDVFactory {
 
-    static Hashtable fBuiltInTypes = new Hashtable();
+    static final Hashtable fBuiltInTypes = new Hashtable();
     static {
         createBuiltInTypes();
     }
