@@ -1,9 +1,10 @@
 /*
- * Copyright 1999-2004 The Apache Software Foundation.
- * 
- * Licensed under the Apache License, Version 2.0 (the "License");
- * you may not use this file except in compliance with the License.
- * You may obtain a copy of the License at
+ * Licensed to the Apache Software Foundation (ASF) under one or more
+ * contributor license agreements.  See the NOTICE file distributed with
+ * this work for additional information regarding copyright ownership.
+ * The ASF licenses this file to You under the Apache License, Version 2.0
+ * (the "License"); you may not use this file except in compliance with
+ * the License.  You may obtain a copy of the License at
  * 
  *      http://www.apache.org/licenses/LICENSE-2.0
  * 
@@ -26,7 +27,7 @@ import java.util.Vector;
  * 
  * @xerces.internal
  *
- * @version $Id: RegexParser.java 320091 2004-10-04 22:07:41Z mrglavas $
+ * @version $Id: RegexParser.java 469061 2006-10-30 04:16:15Z mrglavas $
  */
 class RegexParser {
     static final int T_CHAR = 0;
@@ -205,8 +206,22 @@ class RegexParser {
           case ')': ret = T_RPAREN;         break;
           case '.': ret = T_DOT;            break;
           case '[': ret = T_LBRACKET;       break;
-          case '^': ret = T_CARET;          break;
-          case '$': ret = T_DOLLAR;         break;
+          case '^':
+              if (this.isSet(RegularExpression.XMLSCHEMA_MODE)) {
+                  ret = T_CHAR;
+              }
+              else {
+                  ret = T_CARET;
+              }
+              break;
+          case '$': 
+              if (this.isSet(RegularExpression.XMLSCHEMA_MODE)) {
+                  ret = T_CHAR;
+              }
+              else {
+                  ret = T_DOLLAR;
+              }
+              break;
           case '(':
             ret = T_LPAREN;
             if (this.offset >= this.regexlen)
