@@ -32,7 +32,7 @@ import org.apache.xerces.impl.Constants;
  *
  * @author  Neeraj Bajaj
  * 
- * @version $Id: CMNodeFactory.java 476309 2006-11-17 20:49:31Z mrglavas $
+ * @version $Id: CMNodeFactory.java 511014 2007-02-23 16:53:57Z mrglavas $
  */
 public class CMNodeFactory {
     
@@ -87,10 +87,16 @@ public class CMNodeFactory {
     }//reset()
     
     public CMNode getCMLeafNode(int type, Object leaf, int id, int position) {
-        nodeCountCheck() ;
+        nodeCountCheck();
         return new XSCMLeaf(type, leaf, id, position) ;
     }
     
+    public CMNode getCMRepeatingLeafNode(int type, Object leaf, 
+            int minOccurs, int maxOccurs, int id, int position) {
+        nodeCountCheck();
+        return new XSCMRepeatingLeaf(type, leaf, minOccurs, maxOccurs, id, position);
+    }
+    
     public CMNode getCMUniOpNode(int type, CMNode childNode) {
         nodeCountCheck();
         return new XSCMUniOp(type, childNode) ;
