@@ -58,7 +58,7 @@ import org.w3c.dom.Element;
  * 
  * @xerces.internal  
  * 
- * @version $Id: XSDComplexTypeTraverser.java 446725 2006-09-15 20:40:10Z mrglavas $
+ * @version $Id: XSDComplexTypeTraverser.java 548082 2007-06-17 18:03:46Z mrglavas $
  */
 
 class  XSDComplexTypeTraverser extends XSDAbstractParticleTraverser {
@@ -97,7 +97,7 @@ class  XSDComplexTypeTraverser extends XSDAbstractParticleTraverser {
     
     private SchemaDVFactory schemaFactory = SchemaDVFactory.getInstance();
     
-    private class ComplexTypeRecoverableError extends Exception {
+    private static final class ComplexTypeRecoverableError extends Exception {
         
         private static final long serialVersionUID = 6802729912091130335L;
         
@@ -876,7 +876,7 @@ class  XSDComplexTypeTraverser extends XSDAbstractParticleTraverser {
                 XSParticleDecl particle = new XSParticleDecl();
                 particle.fType = XSParticleDecl.PARTICLE_MODELGROUP;
                 particle.fValue = group;
-                particle.fAnnotations = fParticle.getAnnotations(); 
+                particle.fAnnotations = XSObjectListImpl.EMPTY_LIST; 
                 
                 fParticle = particle;
             }
@@ -941,6 +941,12 @@ class  XSDComplexTypeTraverser extends XSDAbstractParticleTraverser {
             }
             else if (fromAttrGrp.fAttributeWC != null) {
                 toAttrGrp.fAttributeWC = toAttrGrp.fAttributeWC.performUnionWith(fromAttrGrp.fAttributeWC, toAttrGrp.fAttributeWC.fProcessContents);
+                if (toAttrGrp.fAttributeWC == null) {
+                    // REVISIT: XML Schema 1.0 2nd edition doesn't actually specify this constraint. It's a bug in the spec
+                    // which will eventually be fixed. We're just guessing what the error code will be. If it turns out to be
+                    // something else we'll need to change it. -- mrglavas
+                    throw new ComplexTypeRecoverableError("src-ct.5", new Object[]{typeName}, elem);
+                }
             }
             
         }
