@@ -29,6 +29,7 @@ import javax.xml.transform.Source;
 import javax.xml.transform.dom.DOMResult;
 import javax.xml.transform.dom.DOMSource;
 
+import org.apache.xerces.dom.NodeImpl;
 import org.apache.xerces.impl.Constants;
 import org.apache.xerces.impl.XMLErrorReporter;
 import org.apache.xerces.impl.validation.EntityState;
@@ -60,7 +61,7 @@ import org.xml.sax.SAXException;
  * <p>A validator helper for <code>DOMSource</code>s.</p>
  * 
  * @author Michael Glavassevich, IBM
- * @version $Id: DOMValidatorHelper.java 447235 2006-09-18 05:01:44Z mrglavas $
+ * @version $Id: DOMValidatorHelper.java 542517 2007-05-29 13:47:06Z mrglavas $
  */
 final class DOMValidatorHelper implements ValidatorHelper, EntityState {
     
@@ -101,25 +102,25 @@ final class DOMValidatorHelper implements ValidatorHelper, EntityState {
     //
     
     /** Error reporter. */
-    private XMLErrorReporter fErrorReporter;
+    private final XMLErrorReporter fErrorReporter;
     
     /** The namespace context of this document: stores namespaces in scope. **/
-    private NamespaceSupport fNamespaceContext;
+    private final NamespaceSupport fNamespaceContext;
     
     /** The namespace context of the DOMSource, includes context from ancestor nodes. **/
-    private DOMNamespaceContext fDOMNamespaceContext = new DOMNamespaceContext();
+    private final DOMNamespaceContext fDOMNamespaceContext = new DOMNamespaceContext();
     
     /** Schema validator. **/
-    private XMLSchemaValidator fSchemaValidator;
+    private final XMLSchemaValidator fSchemaValidator;
     
     /** Symbol table **/
-    private SymbolTable fSymbolTable;
+    private final SymbolTable fSymbolTable;
     
     /** Validation manager. **/
-    private ValidationManager fValidationManager;
+    private final ValidationManager fValidationManager;
     
     /** Component manager. **/
-    private XMLSchemaValidatorComponentManager fComponentManager;
+    private final XMLSchemaValidatorComponentManager fComponentManager;
     
     /** Simple Locator. **/
     private final SimpleLocator fXMLLocator = new SimpleLocator(null, null, -1, -1, -1);
@@ -137,7 +138,7 @@ final class DOMValidatorHelper implements ValidatorHelper, EntityState {
     private NamedNodeMap fEntities = null;
     
     /** Array for holding character data. **/
-    private char [] fCharBuffer = new char[CHUNK_SIZE];
+    private final char [] fCharBuffer = new char[CHUNK_SIZE];
     
     /** Root node. **/
     private Node fRoot;
@@ -235,6 +236,7 @@ final class DOMValidatorHelper implements ValidatorHelper, EntityState {
     /** Traverse the DOM and fire events to the schema validator. */
     private void validate(Node node) {
         final Node top = node;
+        final boolean useIsSameNode = useIsSameNode(top);
         // Performs a non-recursive traversal of the DOM. This
         // will avoid a stack overflow for DOMs with high depth.
         while (node != null) {
@@ -248,7 +250,8 @@ final class DOMValidatorHelper implements ValidatorHelper, EntityState {
                 next = node.getNextSibling();
                 if (next == null) {
                     node = node.getParentNode();
-                    if (node == null || top == node) {
+                    if (node == null || ((useIsSameNode) ? 
+                        top.isSameNode(node) : top == node)) {
                         if (node != null) {
                             finishNode(node);
                         }
@@ -450,6 +453,22 @@ final class DOMValidatorHelper implements ValidatorHelper, EntityState {
         }
     }
     
+    /**
+     * Use isSameNode() for testing node identity if the DOM implementation
+     * supports DOM Level 3 core and it isn't the Xerces implementation.
+     */
+    private boolean useIsSameNode(Node node) {
+        if (node instanceof NodeImpl) {
+            return false;
+        }
+        Document doc = node.getNodeType() == Node.DOCUMENT_NODE 
+            ? (Document) node : node.getOwnerDocument();
+        return (doc != null && doc.getImplementation().hasFeature("Core", "3.0"));
+    }
+    
+    /**
+     * Returns the current element node.
+     */
     Node getCurrentElement() {
         return fCurrentElement;
     }
