@@ -88,7 +88,7 @@ import org.xml.sax.ext.LexicalHandler;
  * @author Kohsuke Kawaguchi (kohsuke.kawaguchi@sun.com)
  * @author Michael Glavassevich, IBM
  * 
- * @version $Id: ValidatorHandlerImpl.java 447235 2006-09-18 05:01:44Z mrglavas $
+ * @version $Id: ValidatorHandlerImpl.java 542519 2007-05-29 13:54:42Z mrglavas $
  */
 final class ValidatorHandlerImpl extends ValidatorHandler implements
     DTDHandler, EntityState, PSVIProvider, ValidatorHelper, XMLDocumentHandler {
@@ -138,22 +138,22 @@ final class ValidatorHandlerImpl extends ValidatorHandler implements
     //
     
     /** Error reporter. */
-    private XMLErrorReporter fErrorReporter;
+    private final XMLErrorReporter fErrorReporter;
     
     /** The namespace context of this document: stores namespaces in scope */
-    private NamespaceContext fNamespaceContext;
+    private final NamespaceContext fNamespaceContext;
     
     /** Schema validator. **/
-    private XMLSchemaValidator fSchemaValidator;
+    private final XMLSchemaValidator fSchemaValidator;
     
     /** Symbol table **/
-    private SymbolTable fSymbolTable;
+    private final SymbolTable fSymbolTable;
     
     /** Validation manager. */
-    private ValidationManager fValidationManager;
+    private final ValidationManager fValidationManager;
     
     /** Component manager. **/
-    private XMLSchemaValidatorComponentManager fComponentManager;
+    private final XMLSchemaValidatorComponentManager fComponentManager;
 
     /** XML Locator wrapper for SAX. **/
     private final SAXLocatorWrapper fSAXLocatorWrapper = new SAXLocatorWrapper();
