@@ -1,9 +1,10 @@
 /*
- * Copyright 2001-2004 The Apache Software Foundation.
- * 
- * Licensed under the Apache License, Version 2.0 (the "License");
- * you may not use this file except in compliance with the License.
- * You may obtain a copy of the License at
+ * Licensed to the Apache Software Foundation (ASF) under one or more
+ * contributor license agreements.  See the NOTICE file distributed with
+ * this work for additional information regarding copyright ownership.
+ * The ASF licenses this file to You under the Apache License, Version 2.0
+ * (the "License"); you may not use this file except in compliance with
+ * the License.  You may obtain a copy of the License at
  * 
  *      http://www.apache.org/licenses/LICENSE-2.0
  * 
@@ -79,7 +80,7 @@ import org.apache.xerces.xni.parser.XMLPullParserConfiguration;
  * @author Andy Clark, IBM
  * @author Neil Graham, IBM
  *
- * @version $Id: DTDConfiguration.java 319806 2004-02-24 23:15:58Z mrglavas $
+ * @version $Id: DTDConfiguration.java 548192 2007-06-18 03:34:19Z mrglavas $
  */
 public class DTDConfiguration
     extends BasicParserConfiguration 
@@ -352,9 +353,7 @@ public class DTDConfiguration
         fDTDProcessor = createDTDProcessor();
         if (fDTDProcessor != null) {
             setProperty(DTD_PROCESSOR, fDTDProcessor);
-            if (fDTDProcessor instanceof XMLComponent) {
-                addComponent((XMLComponent)fDTDProcessor);
-            }
+            addComponent(fDTDProcessor);
         }
 
         fDTDValidator = createDTDValidator();
