@@ -1,9 +1,10 @@
 /*
- * Copyright 2002,2004,2006 The Apache Software Foundation.
- * 
- * Licensed under the Apache License, Version 2.0 (the "License");
- * you may not use this file except in compliance with the License.
- * You may obtain a copy of the License at
+ * Licensed to the Apache Software Foundation (ASF) under one or more
+ * contributor license agreements.  See the NOTICE file distributed with
+ * this work for additional information regarding copyright ownership.
+ * The ASF licenses this file to You under the Apache License, Version 2.0
+ * (the "License"); you may not use this file except in compliance with
+ * the License.  You may obtain a copy of the License at
  * 
  *      http://www.apache.org/licenses/LICENSE-2.0
  * 
@@ -34,16 +35,7 @@ import java.security.PrivilegedExceptionAction;
  */
 final class SecuritySupport {
 
-    private static final SecuritySupport securitySupport = new SecuritySupport();
-
-    /**
-     * Return an instance of this class.
-     */
-    static SecuritySupport getInstance() {
-        return securitySupport;
-    }
-
-    ClassLoader getContextClassLoader() {
+    static ClassLoader getContextClassLoader() {
         return (ClassLoader)
         AccessController.doPrivileged(new PrivilegedAction() {
             public Object run() {
@@ -56,7 +48,7 @@ final class SecuritySupport {
         });
     }
     
-    ClassLoader getSystemClassLoader() {
+    static ClassLoader getSystemClassLoader() {
         return (ClassLoader)
         AccessController.doPrivileged(new PrivilegedAction() {
             public Object run() {
@@ -69,7 +61,7 @@ final class SecuritySupport {
         });
     }
     
-    ClassLoader getParentClassLoader(final ClassLoader cl) {
+    static ClassLoader getParentClassLoader(final ClassLoader cl) {
         return (ClassLoader)
         AccessController.doPrivileged(new PrivilegedAction() {
             public Object run() {
@@ -85,7 +77,7 @@ final class SecuritySupport {
         });
     }
     
-    String getSystemProperty(final String propName) {
+    static String getSystemProperty(final String propName) {
         return (String)
         AccessController.doPrivileged(new PrivilegedAction() {
             public Object run() {
@@ -94,7 +86,7 @@ final class SecuritySupport {
         });
     }
     
-    FileInputStream getFileInputStream(final File file)
+    static FileInputStream getFileInputStream(final File file)
     throws FileNotFoundException
     {
         try {
@@ -109,7 +101,7 @@ final class SecuritySupport {
         }
     }
     
-    InputStream getResourceAsStream(final ClassLoader cl,
+    static InputStream getResourceAsStream(final ClassLoader cl,
             final String name)
     {
         return (InputStream)
@@ -126,7 +118,7 @@ final class SecuritySupport {
         });
     }
     
-    boolean getFileExists(final File f) {
+    static boolean getFileExists(final File f) {
         return ((Boolean)
                 AccessController.doPrivileged(new PrivilegedAction() {
                     public Object run() {
@@ -135,7 +127,7 @@ final class SecuritySupport {
                 })).booleanValue();
     }
     
-    long getLastModified(final File f) {
+    static long getLastModified(final File f) {
         return ((Long)
                 AccessController.doPrivileged(new PrivilegedAction() {
                     public Object run() {
