@@ -1,9 +1,10 @@
 /*
- * Copyright 1999-2002,2004-2006 The Apache Software Foundation.
- * 
- * Licensed under the Apache License, Version 2.0 (the "License");
- * you may not use this file except in compliance with the License.
- * You may obtain a copy of the License at
+ * Licensed to the Apache Software Foundation (ASF) under one or more
+ * contributor license agreements.  See the NOTICE file distributed with
+ * this work for additional information regarding copyright ownership.
+ * The ASF licenses this file to You under the Apache License, Version 2.0
+ * (the "License"); you may not use this file except in compliance with
+ * the License.  You may obtain a copy of the License at
  * 
  *      http://www.apache.org/licenses/LICENSE-2.0
  * 
@@ -63,9 +64,9 @@ import org.xml.sax.helpers.AttributesImpl;
  * The serializer supports both DOM and SAX. SAX serializing is done by firing
  * SAX events and using the serializer as a document handler. DOM serializing is done
  * by calling {@link #serialize(Document)} or by using DOM Level 3  
- * {@link org.w3c.dom.ls.DOMSerializer} and
- * serializing with {@link org.w3c.dom.ls.DOMSerializer#write},
- * {@link org.w3c.dom.ls.DOMSerializer#writeToString}.
+ * {@link org.w3c.dom.ls.LSSerializer} and
+ * serializing with {@link org.w3c.dom.ls.LSSerializer#write},
+ * {@link org.w3c.dom.ls.LSSerializer#writeToString}.
  * <p>
  * If an I/O exception occurs while serializing, the serializer
  * will not throw an exception directly, but only throw it
@@ -77,10 +78,15 @@ import org.xml.sax.helpers.AttributesImpl;
  * boundaries, indent lines, and serialize elements on separate
  * lines. Line terminators will be regarded as spaces, and
  * spaces at beginning of line will be stripped.
+ * 
+ * @deprecated This class was deprecated in Xerces 2.9.0. It is recommended 
+ * that new applications use the DOM Level 3 LSSerializer or JAXP's Transformation 
+ * API for XML (TrAX) for serializing XML. See the Xerces documentation for more 
+ * information.
  * @author <a href="mailto:arkin@intalio.com">Assaf Arkin</a>
  * @author <a href="mailto:rahul.srivastava@sun.com">Rahul Srivastava</a>
  * @author Elena Litani IBM
- * @version $Revision: 405847 $ $Date: 2006-05-12 15:35:42 -0400 (Fri, 12 May 2006) $
+ * @version $Revision: 476047 $ $Date: 2006-11-16 23:27:45 -0500 (Thu, 16 Nov 2006) $
  * @see Serializer
  */
 public class XMLSerializer
@@ -188,7 +194,7 @@ extends BaseMarkupSerializer {
     /**
      * This methods turns on namespace fixup algorithm during
      * DOM serialization.
-     * @see org.w3c.dom.ls.DOMSerializer
+     * @see org.w3c.dom.ls.LSSerializer
      * 
      * @param namespaces
      */
@@ -215,7 +221,6 @@ extends BaseMarkupSerializer {
         ElementState state;
         String       name;
         String       value;
-        boolean      addNSAttr = false;
 
         if (DEBUG) {
             System.out.println("==>startElement("+namespaceURI+","+localName+
@@ -270,13 +275,16 @@ extends BaseMarkupSerializer {
                 if (namespaceURI != null && ! namespaceURI.equals( "" )) {
                     String prefix;
                     prefix = getPrefix( namespaceURI );
-                    if (prefix != null && prefix.length() > 0)
+                    if (prefix != null && prefix.length() > 0) {
                         rawName = prefix + ":" + localName;
-                    else
+                    } 
+                    else {
                         rawName = localName;
-                } else
+                    }
+                } 
+                else {
                     rawName = localName;
-                addNSAttr = true;
+                }
             }
 
             _printer.printText( '<' );
@@ -763,13 +771,11 @@ extends BaseMarkupSerializer {
                                 //          xmlns:foo = ""
                             }
                             continue;
-                        } else { // xmlns
-                            // empty prefix is always bound ("" or some string)
-
-                            value = fSymbolTable.addSymbol(value);
-                            fNSBinder.declarePrefix(XMLSymbols.EMPTY_STRING, value);
-                            continue;
                         }
+                        // xmlns --- empty prefix is always bound ("" or some string)
+                        value = fSymbolTable.addSymbol(value);
+                        fNSBinder.declarePrefix(XMLSymbols.EMPTY_STRING, value);
+                        continue;
                     }  // end-else: valid declaration
                 } // end-if: namespace declaration 
             }  // end-for
@@ -951,22 +957,20 @@ extends BaseMarkupSerializer {
                                 //          xmlns:foo = ""
                             }
                             continue;
-                        } else { // xmlns
-                            // empty prefix is always bound ("" or some string)
-
-                            uri = fNSBinder.getURI(XMLSymbols.EMPTY_STRING);
-                            localUri=fLocalNSBinder.getURI(XMLSymbols.EMPTY_STRING);
-                            value = fSymbolTable.addSymbol(value);
-                            if (localUri == null ){
-                                // declaration was not printed while fixing element namespace binding
-                                if (fNamespacePrefixes) {
-                                    printNamespaceAttr(XMLSymbols.EMPTY_STRING, value);
-                                }
-                                // case 4 does not apply here since attributes can't use
-                                // default namespace
-                            }
-                            continue;
                         }
+                        // xmlns --- empty prefix is always bound ("" or some string)
+                        uri = fNSBinder.getURI(XMLSymbols.EMPTY_STRING);
+                        localUri= fLocalNSBinder.getURI(XMLSymbols.EMPTY_STRING);
+                        value = fSymbolTable.addSymbol(value);
+                        if (localUri == null ) {
+                            // declaration was not printed while fixing element namespace binding
+                            if (fNamespacePrefixes) {
+                                printNamespaceAttr(XMLSymbols.EMPTY_STRING, value);
+                            }
+                            // case 4 does not apply here since attributes can't use
+                            // default namespace
+                        }
+                        continue;
 
                     }
                     uri = fSymbolTable.addSymbol(uri);
@@ -1188,8 +1192,6 @@ extends BaseMarkupSerializer {
         AttributesImpl attrsOnly;
         String         rawName;
         int            i;
-        int            indexColon;
-        String         prefix;
         int            length;
 
         if (attrs == null) {
@@ -1286,7 +1288,7 @@ extends BaseMarkupSerializer {
                     if (++index <length) {
                         surrogates(ch, text.charAt(index), true);
                     } else {
-                        fatalError("The character '"+(char)ch+"' is an invalid XML character"); 
+                        fatalError("The character '"+ch+"' is an invalid XML character"); 
                     }
                     continue;
                 }
@@ -1308,7 +1310,7 @@ extends BaseMarkupSerializer {
                     if (++index <length) {
                         surrogates(ch, text.charAt(index), true);
                     } else {
-                        fatalError("The character '"+(char)ch+"' is an invalid XML character"); 
+                        fatalError("The character '"+ch+"' is an invalid XML character"); 
                     }
                     continue;
                 }
@@ -1325,8 +1327,6 @@ extends BaseMarkupSerializer {
 
     protected void printText( char[] chars, int start, int length,
                               boolean preserveSpace, boolean unescaped ) throws IOException {
-        int index;
-        char ch;
 
         if ( preserveSpace ) {
             // Preserving spaces: the text must print exactly as it is,
@@ -1334,20 +1334,23 @@ extends BaseMarkupSerializer {
             // consolidating spaces. If a line terminator is used, a line
             // break will occur.
             while ( length-- > 0 ) {
-                ch = chars[start++];
+                char ch = chars[start++];
                 if (!XMLChar.isValid(ch)) {
                     // check if it is surrogate
                     if ( length-- > 0 ) {
                         surrogates(ch, chars[start++], true);
-                    } else {
-                        fatalError("The character '"+(char)ch+"' is an invalid XML character"); 
+                    } 
+                    else {
+                        fatalError("The character '"+ch+"' is an invalid XML character"); 
                     }
                     continue;
                 }
-                if ( unescaped )
+                if ( unescaped ) {
                     _printer.printText( ch );
-                else
+                } 
+                else {
                     printXMLChar( ch );
+                }
             }
         } else {
             // Not preserving spaces: print one part at a time, and
@@ -1356,20 +1359,23 @@ extends BaseMarkupSerializer {
             // by printing mechanism. Line terminator is treated
             // no different than other text part.
             while ( length-- > 0 ) {
-                ch = chars[start++];
+                char ch = chars[start++];
                 if (!XMLChar.isValid(ch)) {
                     // check if it is surrogate
                     if ( length-- > 0 ) {
                         surrogates(ch, chars[start++], true);
-                    } else {
-                        fatalError("The character '"+(char)ch+"' is an invalid XML character"); 
+                    } 
+                    else {
+                        fatalError("The character '"+ch+"' is an invalid XML character"); 
                     }
                     continue;
                 }
-                if ( unescaped )
+                if ( unescaped ) {
                     _printer.printText( ch );
-                else
+                } 
+                else {
                     printXMLChar( ch );
+                }
             }
         }
     }
